@@ -7,7 +7,7 @@ from splitiorequests.models.splits.tag import Tag
 @dataclass
 class Split:
     name: str
-    description: Optional[str] = None
+    description: str = ''
     trafficType: Optional[TrafficType] = None
     creationTime: Optional[int] = None
     tags: Optional[List[Tag]] = None
