@@ -20,7 +20,7 @@ class SplitDefinitionSchema(Schema):
     defaultRule = fields.List(fields.Nested(default_rule_schema.DefaultRuleSchema), required=True)
     creationTime = fields.Int()
     lastUpdateTime = fields.Int()
-    comment = fields.Int()
+    comment = fields.Str()
 
     @post_load
     def load_split_definition(self, data, **kwargs):
