@@ -8,7 +8,7 @@ class SplitSchema(Schema):
         ordered = True
 
     name = fields.Str(required=True)
-    description = fields.Str(missing=None)
+    description = fields.Str()
     trafficType = fields.Nested(traffic_type_schema.TrafficTypeSchema)
     creationTime = fields.Integer()
     tags = fields.List(fields.Nested(tag_schema.TagSchema), missing=None)
